aboutsummaryrefslogtreecommitdiff
path: root/gcc/tree.h
diff options
context:
space:
mode:
authorRichard Kenner <kenner@gcc.gnu.org>1992-09-19 15:44:33 -0400
committerRichard Kenner <kenner@gcc.gnu.org>1992-09-19 15:44:33 -0400
commit17c7332100d72bdb013d40db25cf64617c48ca9e (patch)
tree94f00d720bb0279cc19ab91568c5affa96c46eb1 /gcc/tree.h
parent07be3989ad978ad4916344110279db68f2770690 (diff)
downloadgcc-17c7332100d72bdb013d40db25cf64617c48ca9e.zip
gcc-17c7332100d72bdb013d40db25cf64617c48ca9e.tar.gz
gcc-17c7332100d72bdb013d40db25cf64617c48ca9e.tar.bz2
(DECL_MODE, DECL_RTL): Update comments.
From-SVN: r2172
Diffstat (limited to 'gcc/tree.h')
-rw-r--r--gcc/tree.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/gcc/tree.h b/gcc/tree.h
index 06ef8976..4c70438 100644
--- a/gcc/tree.h
+++ b/gcc/tree.h
@@ -728,9 +728,15 @@ struct tree_type
#define DECL_SIZE(NODE) ((NODE)->decl.size)
/* Holds the alignment required for the datum. */
#define DECL_ALIGN(NODE) ((NODE)->decl.frame_size)
-/* Holds the machine mode of a variable or field. */
+/* Holds the machine mode corresponding to the declaration of a variable or
+ field. Always equal to TYPE_MODE (TREE_TYPE (decl)) except for a
+ FIELD_DECL. */
#define DECL_MODE(NODE) ((NODE)->decl.mode)
-/* Holds the RTL expression for the value of a variable or function. */
+/* Holds the RTL expression for the value of a variable or function. If
+ PROMOTED_MODE is defined, the mode of this expression may not be same
+ as DECL_MODE. In that case, DECL_MODE contains the mode corresponding
+ to the variable's data type, while the mode
+ of DECL_RTL is the mode actually used to contain the data. */
#define DECL_RTL(NODE) ((NODE)->decl.rtl)
/* For PARM_DECL, holds an RTL for the stack slot or register
where the data was actually passed. */